Module: Brainiac::Plugins::Basecamp::Cli

Defined in:
lib/brainiac/plugins/basecamp/cli.rb

Constant Summary collapse

BRAINIAC_DIR =
ENV.fetch("BRAINIAC_DIR", File.join(Dir.home, ".brainiac"))
CONFIG_FILE =
File.join(BRAINIAC_DIR, "basecamp.json")
REQUIRED_WEBHOOK_TYPES =

The canonical set of webhook event types this plugin needs. Add new types here as features are added — webhook sync will pick them up.

%w[Todo Todolist Comment].freeze

Class Method Summary collapse

Class Method Details

.run(args) ⇒ Object



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/brainiac/plugins/basecamp/cli.rb', line 16

def run(args)
  command = args.shift

  case command
  when "setup"
    cmd_setup
  when "config"
    cmd_config
  when "status"
    cmd_status
  when "epics"
    cmd_epics(args)
  when "deploy"
    cmd_deploy(args)
  when "link"
    cmd_link(args)
  when "bot"
    cmd_bot(args)
  when "projects"
    cmd_projects(args)
  when "set"
    cmd_set(args)
  when "reset"
    cmd_reset(args)
  when "scrap"
    cmd_scrap(args)
  when "webhook", "webhooks"
    cmd_webhook(args)
  else
    print_help
  end
end